import { lazy, Suspense } from "react"
import { HashRouter, Routes, Route, Navigate } from "react-router-dom"

import { Layout, Sidebar, Header } from "../components"
import { UnstableProviderProvider, MetadataProviderProvider } from "../hooks"
import { DEFAULT_CHAIN_ID } from "../settings"

const HealthCheck = lazy(() => import("./HealthCheck").then(module => ({ default: module.HealthCheck })))
const Transactions = lazy(() => import("./Transactions").then(module => ({ default: module.Transactions })))
const AddressBook = lazy(() => import("./AddressBook").then(module => ({ default: module.AddressBook })))

export const App = () => {
    return (
        <HashRouter>
            <Suspense fallback={<div></div>}>
                <UnstableProviderProvider defaultChainId={DEFAULT_CHAIN_ID}>
                    <MetadataProviderProvider>
                        <Layout>
                            <Sidebar />
                            <div className="w-full h-full flex flex-col px-6 py-8">
                                <Header />
                                <Routes>
                                    <Route path="/health" element={<HealthCheck />} />
                                    <Route path="/transactions" element={<Transactions />} />
                                    <Route path="/book" element={<AddressBook />} />
                                    <Route path="*" element={<Navigate to="/health" replace />} />
                                </Routes>
                            </div>
                        </Layout>
                    </MetadataProviderProvider>
                </UnstableProviderProvider>
            </Suspense>
        </HashRouter>

    )
}
