import useSWR from "swr"
import { useUnstableProvider } from "./useUnstableProvider"

export type ChainSpecV1Type = {
    chainName: string | undefined
    genesisHash: string | undefined
    properties: {
        tokenSymbol: string | undefined
        tokenDecimals: number | undefined
        ss58Format: number | undefined
    } | undefined
}

export const useChainSpecV1 = () => {
    const { client } = useUnstableProvider()
    const { data: chainSpecV1 } = useSWR(
        client ? ["chainSpec_v1_", client] : null,
        async ([prefix, client]) => {
            const methods = ["chainName", "properties", "genesisHash"]
            const responses = await Promise.all(methods.map((method) => {
                return new Promise<string | undefined>((resolve, reject) =>
                    client._request(`${prefix}${method}`, [], {
                        onSuccess: resolve,
                        onError: reject,
                    }),
                )
                .catch((_) => undefined)
            }))
            return {
                chainName: responses?.at(0) as string | undefined,
                properties: responses?.at(1) as {
                    tokenSymbol: string | undefined
                    tokenDecimals: number | undefined
                    ss58Format: number | undefined
                } | undefined,
                genesisHash: responses?.at(2) as string | undefined
            }
        },
        {
            revalidateOnFocus: false,
            refreshInterval: 0
        }
    )
    return chainSpecV1
}
