import useSWRSubscription from "swr/subscription"
import { getDynamicBuilder, getLookupFn } from "@polkadot-api/metadata-builders"
import type { BlockInfo } from "@polkadot-api/observable-client"
import { distinct, filter, map, mergeMap } from "rxjs"

import { useUnstableProvider } from "./useUnstableProvider"
import { useMetadata } from "./useMetadata"

export type SystemAccountStorage = {
    consumers: number
    data: {
        flags: bigint
        free: bigint
        frozen: bigint
        reserved: bigint
    }
    nonce: number
    providers: number
    sufficients: number
}

export const useSystemAccount = ({ account }: { account: string | undefined }) => {
    const { chainHead$, chainId } = useUnstableProvider()
    const metadata = useMetadata()
    const { data: systemAccount } = useSWRSubscription(
        chainHead$ && chainId && account && metadata
            ? ["systemAccount", chainHead$, chainId, account, metadata]
            : null,
        ([_, chainHead$, chainId, account, metadata], { next }) => {
            const { finalized$, storage$ } = chainHead$
            const subscription = finalized$.pipe(
                filter(Boolean),
                mergeMap((blockInfo: BlockInfo) => {
                    const builder = getDynamicBuilder(getLookupFn(metadata))
                    const storageAccount = builder.buildStorage("System", "Account")
                    return storage$(blockInfo?.hash, "value", () =>
                        storageAccount?.keys.enc(account)
                    ).pipe(
                        filter(Boolean),
                        distinct(),
                        map((value: string) => storageAccount?.value.dec(value) as SystemAccountStorage)
                    )
                }),
            )
            .subscribe({
                next(systemAccount: SystemAccountStorage) {
                    next(null, systemAccount)
                },
                error: next,
            })
            return () => subscription.unsubscribe()
        }
    )
    return systemAccount
}
